@@ -5,7 +5,7 @@ Resources = {
 	"GetResource": () => ({}),
 	"BuildSchema": (type) => {
 		let schema = "";
-		for (let res of Resources.GetCodes())
+		for (const res of Resources.GetCodes())
 			schema +=
 				"<optional>" +
 					"<element name='" + res + "'>" +
@@ -26,12 +26,12 @@ Engine.LoadComponentScript("Timer.js");
 // Resource Trickle requires this function to be defined before the component is built.
 let ApplyValueModificationsToEntity = (valueName, currentValue, entity) => currentValue;
 Engine.RegisterGlobal("ApplyValueModificationsToEntity", ApplyValueModificationsToEntity);
-let wonderEnt = 1;
-let turnLength = 0.2;
-let playerEnt = 10;
-let cmpTimer = ConstructComponent(SYSTEM_ENTITY, "Timer", {});
+const wonderEnt = 1;
+const turnLength = 0.2;
+const playerEnt = 10;
+const cmpTimer = ConstructComponent(SYSTEM_ENTITY, "Timer", {});
 
-let cmpResourceTrickle = ConstructComponent(wonderEnt, "ResourceTrickle", {
+const cmpResourceTrickle = ConstructComponent(wonderEnt, "ResourceTrickle", {
 	"Interval": "200",
 	"Rates": {
 		"food": "0",
@@ -39,7 +39,7 @@ let cmpResourceTrickle = ConstructComponent(wonderEnt, "ResourceTrickle", {
 	}
 });
 
-let cmpPlayer = ConstructComponent(playerEnt, "Player", {
+const cmpPlayer = ConstructComponent(playerEnt, "Player", {
 	"SpyCostMultiplier": "1",
 	"BarterMultiplier": {
 		"Buy": {
@@ -54,7 +54,7 @@ let cmpPlayer = ConstructComponent(playerEnt, "Player", {
 	"Formations": { "_string": "" },
 });
 
-let QueryOwnerInterface = () => cmpPlayer;
+const QueryOwnerInterface = () => cmpPlayer;
 Engine.RegisterGlobal("QueryOwnerInterface", QueryOwnerInterface);
 TS_ASSERT_UNEVAL_EQUALS(cmpPlayer.GetResourceCounts(), { "food": 300, "metal": 300 });
 TS_ASSERT_EQUALS(cmpResourceTrickle.GetInterval(), 200);
