@@ -1,37 +1,32 @@
 function init()
 {
 	var languageList = Engine.GetGUIObjectByName("languageList");
-	languageList.list = Engine.GetSupportedLocaleDisplayNames();
-	languageList.list_data = Engine.GetSupportedLocaleBaseNames();
+	const displayLanguages = Engine.GetSupportedLocaleDisplayNames();
+	const displayLanguagesData = Engine.GetSupportedLocaleBaseNames();
+	languageList.list = displayLanguages.map((name, index) => {
+		return `[locale="${displayLanguagesData[index]}"]${name}[/locale]`;
+	});
+	languageList.list_data = displayLanguagesData;
 
 	var currentLocale = Engine.GetCurrentLocale();
 	var currentLocaleDictName = Engine.GetFallbackToAvailableDictLocale(currentLocale);
-	var useLongStrings = Engine.UseLongStrings();
-	var index = -1;
-	if (useLongStrings)
-		index = languageList.list_data.indexOf("long");
-	if (index == -1)
-		index = languageList.list_data.indexOf(currentLocaleDictName);
+	var index = languageList.list_data.indexOf(currentLocaleDictName);
 
 	if (index != -1)
 		languageList.selected = index;
 
 	var localeText = Engine.GetGUIObjectByName("localeText");
-	if (useLongStrings)
-		localeText.caption = "long";
-	else
-		localeText.caption = currentLocale;
-}
+	localeText.caption = currentLocale;
 
-function cancelSetup()
-{
-	Engine.PopGuiPage();
+	return new Promise(closePageCallback => {
+		Engine.GetGUIObjectByName("cancelButton").onPress = closePageCallback;
+	});
 }
 
 function applySelectedLocale()
 {
 	var localeText = Engine.GetGUIObjectByName("localeText");
-	if(!Engine.SaveLocale(localeText.caption))
+	if (!Engine.SaveLocale(localeText.caption))
 	{
 		warn("Selected locale could not be saved in the configuration!");
 		return;
@@ -46,32 +41,27 @@ function languageSelectionChanged()
 	var locale = languageList.list_data[languageList.selected];
 	if (locale == "long")
 		warn("'long' is not an actual language, just a collection of all longest strings extracted from some languages");
-	else if(!Engine.ValidateLocale(locale))
+	else if (!Engine.ValidateLocale(locale))
 		warn("Selected locale is not valid! This is not expected, please report the issue.");
 	var localeText = Engine.GetGUIObjectByName("localeText");
 	localeText.caption = locale;
 }
 
-function openAdvancedMenu()
+async function openAdvancedMenu()
 {
-	let localeText = Engine.GetGUIObjectByName("localeText");
-	Engine.PushGuiPage("page_locale_advanced.xml", { "locale": localeText.caption }, applyFromAdvancedMenu);
-}
+	const localeText = Engine.GetGUIObjectByName("localeText");
+	const locale = await Engine.OpenChildPage("page_locale_advanced.xml", { "locale": localeText.caption });
 
-function applyFromAdvancedMenu(locale)
-{
 	if (!locale)
 		return;
 
 	var languageList = Engine.GetGUIObjectByName("languageList");
 
 	var currentLocaleDictName = Engine.GetFallbackToAvailableDictLocale(locale);
-	var index = -1;
-	index = languageList.list_data.indexOf(currentLocaleDictName);
+	const index = languageList.list_data.indexOf(currentLocaleDictName);
 
 	if (index != -1)
 		languageList.selected = index;
 
-	var localeText = Engine.GetGUIObjectByName("localeText");
 	localeText.caption = locale;
 }
