@@ -15,12 +15,15 @@
  * No further changes should be applied to the image to keep it easily interchangeable.
  */
 
+import { addAnimals, addBerries, addDecoration, addFish, addForests, addLayeredPatches, addMetal, addStone,
+	addStragglerTrees } from "maps/random/rmgen2/gaia.js";
+import { addElements, createBases, initTileClasses } from "maps/random/rmgen2/setup.js";
+
 Engine.LoadLibrary("rmgen");
 Engine.LoadLibrary("rmgen-common");
-Engine.LoadLibrary("rmgen2");
 Engine.LoadLibrary("rmbiome");
 
-function* GenerateMap(mapSettings)
+export function* generateMap(mapSettings)
 {
 	TILE_CENTERED_HEIGHT_MAP = true;
 
@@ -122,11 +125,11 @@ function* GenerateMap(mapSettings)
 		]);
 	yield 45;
 
-	if (!isNomad())
+	if (!mapSettings.Nomad)
 	{
 		g_Map.log("Placing players");
 		const [playerIDs, playerPosition] = createBases(
-			...playerPlacementRandom(
+			playerPlacementRandom(
 				sortAllPlayers(),
 				[
 					avoidClasses(g_TileClasses.mountain, scaleByMapSize(5, 10)),
