@@ -26,11 +26,6 @@ var g_PlayerBaseFunctions = [
 	"Decoratives"
 ];
 
-function isNomad()
-{
-	return !!g_MapSettings.Nomad;
-}
-
 function getNumPlayers()
 {
 	return g_MapSettings.PlayerData.length - 1;
@@ -76,7 +71,7 @@ function placeStartingEntities(location, playerID, civEntities, dist = 6, orient
 {
 	// Place the central structure
 	let i = 0;
-	let firstTemplate = civEntities[i].Template;
+	const firstTemplate = civEntities[i].Template;
 	if (firstTemplate.startsWith("structures/"))
 	{
 		g_Map.placeEntityPassable(firstTemplate, playerID, location, orientation);
@@ -84,15 +79,15 @@ function placeStartingEntities(location, playerID, civEntities, dist = 6, orient
 	}
 
 	// Place entities surrounding it
-	let space = 2;
+	const space = 2;
 	for (let j = i; j < civEntities.length; ++j)
 	{
-		let angle = orientation - Math.PI * (1 - j / 2);
-		let count = civEntities[j].Count || 1;
+		const angle = orientation - Math.PI * (1 - j / 2);
+		const count = civEntities[j].Count || 1;
 
 		for (let num = 0; num < count; ++num)
 		{
-			let position = Vector2D.sum([
+			const position = Vector2D.sum([
 				location,
 				new Vector2D(dist, 0).rotate(-angle),
 				new Vector2D(space * (-num + (count - 1) / 2), 0).rotate(angle)
@@ -118,7 +113,7 @@ function placeCivDefaultStartingEntities(position, playerID, wallType, dist = 6,
  */
 function placeStartingWalls(position, playerID, wallType, orientation = BUILDING_ORIENTATION)
 {
-	let civ = getCivCode(playerID);
+	const civ = getCivCode(playerID);
 	if (civ != "iber" || g_Map.getSize() <= 128)
 		return;
 
@@ -138,7 +133,8 @@ function placePlayerBases(playerBaseArgs)
 {
 	g_Map.log("Creating playerbases");
 
-	let [playerIDs, playerPosition] = playerBaseArgs.PlayerPlacement;
+	const [playerIDs, playerPosition] = Array.isArray(playerBaseArgs.PlayerPlacement) ?
+		playerBaseArgs.PlayerPlacement : Object.values(playerBaseArgs.PlayerPlacement);
 
 	for (let i = 0; i < getNumPlayers(); ++i)
 	{
@@ -153,31 +149,41 @@ function placePlayerBases(playerBaseArgs)
  */
 function placePlayerBase(playerBaseArgs)
 {
-	if (isNomad())
+	if (g_MapSettings.Nomad)
 		return;
 
-	placeCivDefaultStartingEntities(playerBaseArgs.playerPosition, playerBaseArgs.playerID, playerBaseArgs.Walls !== undefined ? playerBaseArgs.Walls : true);
+	placeCivDefaultStartingEntities(
+		playerBaseArgs.playerPosition,
+		playerBaseArgs.playerID,
+		playerBaseArgs.Walls !== undefined ? playerBaseArgs.Walls : true,
+		6,
+		BUILDING_ORIENTATION);
 
 	if (playerBaseArgs.PlayerTileClass)
 		addCivicCenterAreaToClass(playerBaseArgs.playerPosition, playerBaseArgs.PlayerTileClass);
 
-	for (let functionID of g_PlayerBaseFunctions)
+	const baseResourceConstraint = new AndConstraint([
+		playerBaseArgs.BaseResourceClass ? avoidClasses(playerBaseArgs.BaseResourceClass, 4) : [],
+		playerBaseArgs.baseResourceConstraint || []
+	].flat());
+
+	for (const functionID of g_PlayerBaseFunctions)
 	{
-		let funcName = "placePlayerBase" + functionID;
-		let func = global[funcName];
+		const funcName = "placePlayerBase" + functionID;
+		const func = global[funcName];
 		if (!func)
 			throw new Error("Could not find " + funcName);
 
 		if (!playerBaseArgs[functionID])
 			continue;
 
-		let args = playerBaseArgs[functionID];
+		const args = playerBaseArgs[functionID];
 
 		// Copy some global arguments to the arguments for each function
-		for (let prop of ["playerID", "playerPosition", "BaseResourceClass", "baseResourceConstraint"])
+		for (const prop of ["playerID", "playerPosition", "BaseResourceClass"])
 			args[prop] = playerBaseArgs[prop];
 
-		func(args);
+		func(args, baseResourceConstraint);
 	}
 }
 
@@ -197,68 +203,48 @@ function addCivicCenterAreaToClass(position, tileClass)
 		new TileClassPainter(tileClass));
 }
 
-/**
- * Helper function.
- */
-function getPlayerBaseArgs(playerBaseArgs)
-{
-	let baseResourceConstraint = playerBaseArgs.BaseResourceClass && avoidClasses(playerBaseArgs.BaseResourceClass, 4);
-
-	if (playerBaseArgs.baseResourceConstraint)
-		baseResourceConstraint = new AndConstraint([baseResourceConstraint, playerBaseArgs.baseResourceConstraint]);
-
-	return [
-		(property, defaultVal) => playerBaseArgs[property] === undefined ? defaultVal : playerBaseArgs[property],
-		playerBaseArgs.playerPosition,
-		baseResourceConstraint
-	];
-}
-
 function placePlayerBaseCityPatch(args)
 {
-	let [get, basePosition, baseResourceConstraint] = getPlayerBaseArgs(args);
-
 	let painters = [];
 
 	if (args.outerTerrain && args.innerTerrain)
-		painters.push(new LayeredPainter([args.outerTerrain, args.innerTerrain], [get("width", 1)]));
+		painters.push(new LayeredPainter([args.outerTerrain, args.innerTerrain], [args.width ?? 1]));
 
 	if (args.painters)
 		painters = painters.concat(args.painters);
 
 	createArea(
 		new ClumpPlacer(
-			Math.floor(diskArea(get("radius", defaultPlayerBaseRadius() / 3))),
-			get("coherence", 0.6),
-			get("smoothness", 0.3),
-			get("failFraction", Infinity),
-			basePosition),
+			Math.floor(diskArea(args.radius ?? (defaultPlayerBaseRadius() / 3))),
+			args.coherence ?? 0.6,
+			args.smoothness ?? 0.3,
+			args.failFraction ?? Infinity,
+			args.playerPosition),
 		painters);
 }
 
-function placePlayerBaseStartingAnimal(args)
+function placePlayerBaseStartingAnimal(args, baseResourceConstraint)
 {
-	let [get, basePosition, baseResourceConstraint] = getPlayerBaseArgs(args);
-
-	const template = get("template", "gaia/fauna_chicken");
+	const template = args.template ?? "gaia/fauna_chicken";
 	const count = template === "gaia/fauna_chicken" ? 5 :
-		Math.round(5 * (Engine.GetTemplate("gaia/fauna_chicken").ResourceSupply.Max / Engine.GetTemplate(get("template")).ResourceSupply.Max))
+		Math.round(5 * (Engine.GetTemplate("gaia/fauna_chicken").ResourceSupply.Max / Engine.GetTemplate(args.template).ResourceSupply.Max));
 
-	for (let i = 0; i < get("groupCount", 2); ++i)
+	for (let i = 0; i < (args.groupCount ?? 2); ++i)
 	{
 		let success = false;
-		for (let tries = 0; tries < get("maxTries", 30); ++tries)
+		for (let tries = 0; tries < (args.maxTries ?? 30); ++tries)
 		{
-			let position = new Vector2D(0, get("distance", 9)).rotate(randomAngle()).add(basePosition);
+			const position = new Vector2D(0, args.distance ?? 9).rotate(randomAngle()).add(
+				args.playerPosition);
 			if (createObjectGroup(
 				new SimpleGroup(
 					[
 						new SimpleObject(
 							template,
-							get("minGroupCount", count),
-							get("maxGroupCount", count),
-							get("minGroupDistance", 0),
-							get("maxGroupDistance", 2))
+							args.minGroupCount ?? count,
+							args.maxGroupCount ?? count,
+							args.minGroupDistance ?? 0,
+							args.maxGroupDistance ?? 2)
 					],
 					true,
 					args.BaseResourceClass,
@@ -279,15 +265,16 @@ function placePlayerBaseStartingAnimal(args)
 	}
 }
 
-function placePlayerBaseBerries(args)
+function placePlayerBaseBerries(args, baseResourceConstraint)
 {
-	let [get, basePosition, baseResourceConstraint] = getPlayerBaseArgs(args);
-	for (let tries = 0; tries < get("maxTries", 30); ++tries)
+	for (let tries = 0; tries < (args.maxTries ?? 30); ++tries)
 	{
-		let position = new Vector2D(0, get("distance", 12)).rotate(randomAngle()).add(basePosition);
+		const position =
+			new Vector2D(0, args.distance ?? 12).rotate(randomAngle()).add(args.playerPosition);
 		if (createObjectGroup(
 			new SimpleGroup(
-				[new SimpleObject(args.template, get("minCount", 5), get("maxCount", 5), get("maxDist", 1), get("maxDist", 3))],
+				[new SimpleObject(args.template, args.minCount ?? 5, args.maxCount ?? 5,
+					args.minDist ?? 1, args.maxDist ?? 3)],
 				true,
 				args.BaseResourceClass,
 				position),
@@ -299,26 +286,25 @@ function placePlayerBaseBerries(args)
 	error("Could not place berries for player " + args.playerID);
 }
 
-function placePlayerBaseMines(args)
+function placePlayerBaseMines(args, baseResourceConstraint)
 {
-	let [get, basePosition, baseResourceConstraint] = getPlayerBaseArgs(args);
-
-	let angleBetweenMines = randFloat(get("minAngle", Math.PI / 6), get("maxAngle", Math.PI / 3));
-	let mineCount = args.types.length;
+	const angleBetweenMines = randFloat(args.minAngle ?? (Math.PI / 6), args.maxAngle ?? (Math.PI / 3));
+	const mineCount = args.types.length;
 
 	let groupElements = [];
 	if (args.groupElements)
 		groupElements = groupElements.concat(args.groupElements);
 
-	for (let tries = 0; tries < get("maxTries", 75); ++tries)
+	for (let tries = 0; tries < (args.maxTries ?? 75); ++tries)
 	{
 		// First find a place where all mines can be placed
 		let pos = [];
-		let startAngle = randomAngle();
+		const startAngle = randomAngle();
 		for (let i = 0; i < mineCount; ++i)
 		{
-			let angle = startAngle + angleBetweenMines * (i + (mineCount - 1) / 2);
-			pos[i] = new Vector2D(0, get("distance", 12)).rotate(angle).add(basePosition).round();
+			const angle = startAngle + angleBetweenMines * (i + (mineCount - 1) / 2);
+			pos[i] = new Vector2D(0, args.distance ?? 12).rotate(angle).add(
+				args.playerPosition).round();
 			if (!g_Map.validTilePassable(pos[i]) || !baseResourceConstraint.allows(pos[i]))
 			{
 				pos = undefined;
@@ -353,19 +339,19 @@ function placePlayerBaseMines(args)
 	error("Could not place mines for player " + args.playerID);
 }
 
-function placePlayerBaseTrees(args)
+function placePlayerBaseTrees(args, baseResourceConstraint)
 {
-	let [get, basePosition, baseResourceConstraint] = getPlayerBaseArgs(args);
+	const num = Math.floor(args.count ?? scaleByMapSize(7, 20));
 
-	let num = Math.floor(get("count", scaleByMapSize(7, 20)));
-
-	for (let x = 0; x < get("maxTries", 30); ++x)
+	for (let x = 0; x < (args.maxTries ?? 30); ++x)
 	{
-		let position = new Vector2D(0, randFloat(get("minDist", 11), get("maxDist", 13))).rotate(randomAngle()).add(basePosition).round();
+		const position = new Vector2D(0, randFloat(args.minDist ?? 11, args.maxDist ?? 13))
+			.rotate(randomAngle()).add(args.playerPosition).round();
 
 		if (createObjectGroup(
 			new SimpleGroup(
-				[new SimpleObject(args.template, num, num, get("minDistGroup", 0), get("maxDistGroup", 5))],
+				[new SimpleObject(args.template, num, num, args.minDistGroup ?? 0,
+					args.maxDistGroup ?? 5)],
 				false,
 				args.BaseResourceClass,
 				position),
@@ -377,23 +363,23 @@ function placePlayerBaseTrees(args)
 	error("Could not place starting trees for player " + args.playerID);
 }
 
-function placePlayerBaseTreasures(args)
+function placePlayerBaseTreasures(args, baseResourceConstraint)
 {
-	let [get, basePosition, baseResourceConstraint] = getPlayerBaseArgs(args);
-
-	for (let resourceTypeArgs of args.types)
+	for (const resourceTypeArgs of args.types)
 	{
-		get = (property, defaultVal) => resourceTypeArgs[property] === undefined ? defaultVal : resourceTypeArgs[property];
-
 		let success = false;
 
-		for (let tries = 0; tries < get("maxTries", 30); ++tries)
+		for (let tries = 0; tries < (resourceTypeArgs.maxTries ?? 30); ++tries)
 		{
-			let position = new Vector2D(0, randFloat(get("minDist", 11), get("maxDist", 13))).rotate(randomAngle()).add(basePosition).round();
+			const position = new Vector2D(0,
+				randFloat(resourceTypeArgs.minDist ?? 11, resourceTypeArgs.maxDist ?? 13))
+				.rotate(randomAngle()).add(args.playerPosition).round();
 
 			if (createObjectGroup(
 				new SimpleGroup(
-					[new SimpleObject(resourceTypeArgs.template, get("count", 14), get("count", 14), get("minDistGroup", 1), get("maxDistGroup", 3))],
+					[new SimpleObject(resourceTypeArgs.template, resourceTypeArgs.count ?? 14,
+						resourceTypeArgs.count ?? 14, resourceTypeArgs.minDistGroup ?? 1,
+						resourceTypeArgs.maxDistGroup ?? 3)],
 					false,
 					args.BaseResourceClass,
 					position),
@@ -415,20 +401,21 @@ function placePlayerBaseTreasures(args)
 /**
  * Typically used for placing grass tufts around the civic centers.
  */
-function placePlayerBaseDecoratives(args)
+function placePlayerBaseDecoratives(args, baseResourceConstraint)
 {
-	let [get, basePosition, baseResourceConstraint] = getPlayerBaseArgs(args);
-
-	for (let i = 0; i < get("count", scaleByMapSize(2, 5)); ++i)
+	for (let i = 0; i < (args.count ?? scaleByMapSize(2, 5)); ++i)
 	{
 		let success = false;
-		for (let x = 0; x < get("maxTries", 30); ++x)
+		for (let x = 0; x < (args.maxTries ?? 30); ++x)
 		{
-			let position = new Vector2D(0, randIntInclusive(get("minDist", 8), get("maxDist", 11))).rotate(randomAngle()).add(basePosition).round();
+			const position = new Vector2D(0,
+				randIntInclusive(args.minDist ?? 8, args.maxDist ?? 11))
+				.rotate(randomAngle()).add(args.playerPosition).round();
 
 			if (createObjectGroup(
 				new SimpleGroup(
-					[new SimpleObject(args.template, get("minCount", 2), get("maxCount", 5), 0, 1)],
+					[new SimpleObject(args.template, args.minCount ?? 2, args.maxCount ?? 5, 0,
+						1)],
 					false,
 					args.BaseResourceClass,
 					position),
@@ -447,30 +434,30 @@ function placePlayerBaseDecoratives(args)
 
 function placePlayersNomad(playerClass, constraints)
 {
-	if (!isNomad())
+	if (!g_MapSettings.Nomad)
 		return undefined;
 
 	g_Map.log("Placing nomad starting units");
 
-	let distance = scaleByMapSize(60, 240);
-	let constraint = new StaticConstraint(constraints);
+	const distance = scaleByMapSize(60, 240);
+	const constraint = new StaticConstraint(constraints);
 
-	let numPlayers = getNumPlayers();
-	let playerIDs = shuffleArray(sortAllPlayers());
-	let playerPosition = [];
+	const numPlayers = getNumPlayers();
+	const playerIDs = shuffleArray(getPlayerIDs());
+	const playerPosition = [];
 
 	for (let i = 0; i < numPlayers; ++i)
 	{
-		let objects = getStartingEntities(playerIDs[i]).filter(ents => ents.Template.startsWith("units/")).map(
+		const objects = getStartingEntities(playerIDs[i]).filter(ents => ents.Template.startsWith("units/")).map(
 			ents => new SimpleObject(ents.Template, ents.Count || 1, ents.Count || 1, 1, 3));
 
 		// Add treasure if too few resources for a civic center
-		let ccCost = Engine.GetTemplate("structures/" + getCivCode(playerIDs[i]) + "/civil_centre").Cost.Resources;
-		for (let resourceType in ccCost)
+		const ccCost = Engine.GetTemplate("structures/" + getCivCode(playerIDs[i]) + "/civil_centre").Cost.Resources;
+		for (const resourceType in ccCost)
 		{
-			let treasureTemplate = g_NomadTreasureTemplates[resourceType];
+			const treasureTemplate = g_NomadTreasureTemplates[resourceType];
 
-			let count = Math.max(0, Math.ceil(
+			const count = Math.max(0, Math.ceil(
 				(ccCost[resourceType] - (g_MapSettings.StartingResources || 0)) /
 				Engine.GetTemplate(treasureTemplate).Treasure.Resources[resourceType]));
 
@@ -478,9 +465,9 @@ function placePlayersNomad(playerClass, constraints)
 		}
 
 		// Try place these entities at a random location
-		let group = new SimpleGroup(objects, true, playerClass);
+		const group = new SimpleGroup(objects, true, playerClass);
 		let success = false;
-		for (let distanceFactor of [1, 1/2, 1/4, 0])
+		for (const distanceFactor of [1, 1/2, 1/4, 0])
 			if (createObjectGroups(group, playerIDs[i], new AndConstraint([constraint, avoidClasses(playerClass, distance * distanceFactor)]), 1, 200, false).length)
 			{
 				success = true;
@@ -496,8 +483,18 @@ function placePlayersNomad(playerClass, constraints)
 }
 
 /**
- * Sorts an array of player IDs by team index. Players without teams come first.
- * Randomize order for players of the same team.
+ * Get the player IDs
+ *
+ * @returns {Array} - an array with sequential integers from 1 to the number of players
+ */
+function getPlayerIDs()
+{
+	return Array.from(Array(getNumPlayers()), (_, index) => index + 1);
+}
+
+/**
+ * Sorts an array of player IDs by team index.
+ * Players without teams come first. Randomize order for players of the same team.
  */
 function sortPlayers(playerIDs)
 {
@@ -511,11 +508,7 @@ function sortPlayers(playerIDs)
  */
 function sortAllPlayers()
 {
-	let playerIDs = [];
-	for (let i = 0; i < getNumPlayers(); ++i)
-		playerIDs.push(i+1);
-
-	return sortPlayers(playerIDs);
+	return sortPlayers(getPlayerIDs());
 }
 
 /**
@@ -523,7 +516,7 @@ function sortAllPlayers()
  */
 function primeSortPlayers(playerIDs)
 {
-	let prime = [];
+	const prime = [];
 	for (let i = 0; i < Math.floor(playerIDs.length / 2); ++i)
 	{
 		prime.push(playerIDs[i]);
@@ -547,14 +540,14 @@ function primeSortAllPlayers()
  */
 function partitionPlayers(playerIDs)
 {
-	let teamIDs = Array.from(new Set(playerIDs.map(getPlayerTeam)));
+	const teamIDs = Array.from(new Set(playerIDs.map(getPlayerTeam)));
 	let teams = teamIDs.map(teamID => playerIDs.filter(playerID => getPlayerTeam(playerID) == teamID));
 	if (teamIDs.indexOf(-1) != -1)
 		teams = teams.concat(teams.splice(teamIDs.indexOf(-1), 1)[0].map(playerID => [playerID]));
 
 	if (teams.length == 1)
 	{
-		let idx = Math.floor(teams[0].length / 2);
+		const idx = Math.floor(teams[0].length / 2);
 		teams = [teams[0].slice(idx), teams[0].slice(0, idx)];
 	}
 
@@ -565,7 +558,63 @@ function partitionPlayers(playerIDs)
 		east.length > west.length ?
 			[east, west.concat(team)] :
 			[east.concat(team), west],
-		[[], []]);
+	[[], []]);
+}
+
+/**
+ * Return an array where each element is an array of playerIndices of a team.
+ */
+function getTeamsArray()
+{
+	const playerIDs = getPlayerIDs();
+	const numPlayers = getNumPlayers();
+
+	// Group players by team
+	const teams = [];
+	for (let i = 0; i < numPlayers; ++i)
+	{
+		const team = getPlayerTeam(playerIDs[i]);
+		if (team == -1)
+			continue;
+
+		if (!teams[team])
+			teams[team] = [];
+
+		teams[team].push(playerIDs[i]);
+	}
+
+	// Players without a team get a custom index
+	for (let i = 0; i < numPlayers; ++i)
+		if (getPlayerTeam(playerIDs[i]) == -1)
+			teams.push([playerIDs[i]]);
+
+	// Remove unused indices
+	return teams.filter(team => true);
+}
+
+/**
+ * Determine player starting positions based on the specified pattern.
+ */
+function playerPlacementByPattern(patternName, distance = undefined, groupedDistance = undefined, angle = undefined, center = undefined)
+{
+	if (patternName === undefined)
+		patternName = g_MapSettings.PlayerPlacement;
+
+	switch (patternName)
+	{
+	case "circle":
+		return playerPlacementCircle(distance, angle, center);
+	case "river":
+		return playerPlacementRiver(angle, distance, center);
+	case "groupedLines":
+		return placeLine(getTeamsArray(), distance, groupedDistance, angle);
+	case "stronghold":
+		return placeStronghold(getTeamsArray(), distance, groupedDistance * 1.4, angle);
+	case "randomGroup":
+		return playerPlacementRandom(getPlayerIDs(), undefined);
+	default:
+		throw new Error("Unknown placement pattern: " + patternName);
+	}
 }
 
 /**
@@ -573,9 +622,14 @@ function partitionPlayers(playerIDs)
  */
 function playerPlacementCircle(radius, startingAngle = undefined, center = undefined)
 {
-	let startAngle = startingAngle !== undefined ? startingAngle : randomAngle();
-	let [playerPosition, playerAngle] = distributePointsOnCircle(getNumPlayers(), startAngle, radius, center || g_Map.getCenter());
-	return [sortAllPlayers(), playerPosition.map(p => p.round()), playerAngle, startAngle];
+	const startAngle = startingAngle !== undefined ? startingAngle : randomAngle();
+	const [playerPosition, playerAngle] = distributePointsOnCircle(getNumPlayers(), startAngle, radius, center || g_Map.getCenter());
+	return {
+		"playerIDs": getPlayerIDs(),
+		"playerPosition": playerPosition.map(p => p.round()),
+		"playerAngle": playerAngle,
+		"startAngle": startAngle
+	};
 }
 
 /**
@@ -584,10 +638,10 @@ function playerPlacementCircle(radius, startingAngle = undefined, center = undef
  */
 function playerPlacementCustomAngle(radius, center, playerAngleFunc)
 {
-	let playerPosition = [];
-	let playerAngle = [];
+	const playerPosition = [];
+	const playerAngle = [];
 
-	let numPlayers = getNumPlayers();
+	const numPlayers = getNumPlayers();
 
 	for (let i = 0; i < numPlayers; ++i)
 	{
@@ -617,9 +671,9 @@ function playerPlacementArc(playerIDs, center, radius, startAngle, endAngle)
  */
 function playerPlacementArcs(playerIDs, center, radius, mapAngle, startAngle, endAngle)
 {
-	let [east, west] = partitionPlayers(playerIDs);
-	let eastPosition = playerPlacementArc(east, center, radius, mapAngle + startAngle, mapAngle + endAngle);
-	let westPosition = playerPlacementArc(west, center, radius, mapAngle - startAngle, mapAngle - endAngle);
+	const [east, west] = partitionPlayers(playerIDs);
+	const eastPosition = playerPlacementArc(east, center, radius, mapAngle + startAngle, mapAngle + endAngle);
+	const westPosition = playerPlacementArc(west, center, radius, mapAngle - startAngle, mapAngle - endAngle);
 	return playerIDs.map(playerID => east.indexOf(playerID) != -1 ?
 		eastPosition[east.indexOf(playerID)] :
 		westPosition[west.indexOf(playerID)]);
@@ -632,18 +686,18 @@ function playerPlacementArcs(playerIDs, center, radius, mapAngle, startAngle, en
  */
 function playerPlacementRiver(angle, width, center = undefined)
 {
-	let numPlayers = getNumPlayers();
-	let numPlayersEven = numPlayers % 2 == 0;
-	let mapSize = g_Map.getSize();
-	let centerPosition = center || g_Map.getCenter();
-	let playerPosition = [];
+	const numPlayers = getNumPlayers();
+	const numPlayersEven = numPlayers % 2 == 0;
+	const mapSize = g_Map.getSize();
+	const centerPosition = center || g_Map.getCenter();
+	const playerPosition = [];
 
 	for (let i = 0; i < numPlayers; ++i)
 	{
-		let currentPlayerEven = i % 2 == 0;
+		const currentPlayerEven = i % 2 == 0;
 
-		let offsetDivident = numPlayersEven || currentPlayerEven ? (i + 1) % 2 : 0;
-		let offsetDivisor = numPlayersEven ? 0 : currentPlayerEven ? +1 : -1;
+		const offsetDivident = numPlayersEven || currentPlayerEven ? (i + 1) % 2 : 0;
+		const offsetDivisor = numPlayersEven ? 0 : currentPlayerEven ? +1 : -1;
 
 		playerPosition[i] = new Vector2D(
 			width * (i % 2) + (mapSize - width) / 2,
@@ -660,8 +714,8 @@ function playerPlacementRiver(angle, width, center = undefined)
  */
 function playerPlacementLine(angle, center, width)
 {
-	let playerPosition = [];
-	let numPlayers = getNumPlayers();
+	const playerPosition = [];
+	const numPlayers = getNumPlayers();
 
 	for (let i = 0; i < numPlayers; ++i)
 		playerPosition[i] = Vector2D.add(
@@ -675,6 +729,108 @@ function playerPlacementLine(angle, center, width)
 	return playerPosition;
 }
 
+/**
+ * Place teams in a line-pattern.
+ *
+ * @param {Array} playerIDs - typically randomized indices of players of a single team
+ * @param {number} distance - radial distance from the center of the map
+ * @param {number} groupedDistance - distance between players
+ * @param {number} startAngle - determined by the map that might want to place something between players.
+ *
+ * @returns {Array} - contains id, angle, x, z for every player
+ */
+function placeLine(teamsArray, distance, groupedDistance, startAngle)
+{
+	const playerIDs = [];
+	const playerPosition = [];
+
+	const mapCenter = g_Map.getCenter();
+	const numAcross = 2 * getNumPlayers() / teamsArray.length; // if its two teams, numAcross is the same as numPlayers.
+	const dist = fractionToTiles(numAcross == 2 ? 0.45 : 0.66 + (-0.01 * numAcross));
+	groupedDistance *= (3.00 + (-0.225 * numAcross));
+	for (let i = 0; i < teamsArray.length; ++i)
+	{
+		let safeDist = distance;
+		if (distance + teamsArray[i].length * groupedDistance > dist)
+			safeDist = dist - teamsArray[i].length * groupedDistance;
+
+		const teamAngle = startAngle + (i + 1) * 2 * Math.PI / teamsArray.length;
+
+		for (let p = 0; p < teamsArray[i].length; ++p)
+		{
+			playerIDs.push(teamsArray[i][p]);
+			playerPosition.push(Vector2D.add(mapCenter, new Vector2D(safeDist + p * groupedDistance, 0).rotate(-teamAngle)).round());
+		}
+	}
+
+	return {
+		"playerIDs": playerIDs,
+		"playerPosition": playerPosition
+	};
+}
+
+/**
+ * Place given players in a stronghold-pattern.
+ *
+ * @param teamsArray - each item is an array of playerIDs placed per stronghold
+ * @param distance - radial distance from the center of the map
+ * @param groupedDistance - distance between neighboring players
+ * @param {number} startAngle - determined by the map that might want to place something between players
+ */
+function placeStronghold(teamsArray, distance, groupedDistance, startAngle)
+{
+	const mapCenter = g_Map.getCenter();
+
+	const playerIDs = [];
+	const playerPosition = [];
+	const teamPositions = [];
+	const strongholdRadius = teamsArray.map(team => {
+		// If we have a solo player, place them on the center of the team's location
+		if (team.length == 1)
+			return 0;
+
+		return groupedDistance / 2 / Math.sin(Math.PI / team.length);
+	});
+
+	const distanceBetweenStrongholds = (distance * 2 * Math.PI -
+		2 * strongholdRadius.reduce((a, b) => a + b)) / strongholdRadius.length;
+
+	const relativeTeamAngles = strongholdRadius.map((r1, i) => {
+		return (distanceBetweenStrongholds + strongholdRadius.at(i - 1) + r1) / distance;
+	});
+
+	const teamAngles = relativeTeamAngles.reduce((acc, angle, i) => {
+		acc.push((i === 0 ? startAngle : acc.at(-1)) + angle);
+		return acc;
+	}, []);
+
+	for (let i = 0; i < teamsArray.length; ++i)
+	{
+		const teamPosition = Vector2D.add(mapCenter,
+			new Vector2D(distance * 0.8, 0).rotate(-teamAngles[i]));
+
+		// TODO: Ensure players are not placed outside of the map area, similar to placeLine
+
+		// Create player base
+		for (let p = 0; p < teamsArray[i].length; ++p)
+		{
+			const angle = startAngle + (p + 1) * 2 * Math.PI / teamsArray[i].length;
+			playerIDs.push(teamsArray[i][p]);
+			playerPosition.push(Vector2D.add(teamPosition,
+				new Vector2D(strongholdRadius[i], 0).rotate(-angle)).round());
+		}
+		teamPositions.push(teamPosition);
+	}
+
+	return {
+		"playerIDs": playerIDs,
+		"playerPosition": playerPosition,
+		"teamPosition": teamPositions,
+		"teamAngle": teamAngles,
+		"strongholdRadius": strongholdRadius
+	};
+}
+
 /**
  * Returns a random location for each player that meets the given constraints and
  * orders the playerIDs so that players become grouped by team.
@@ -685,11 +841,11 @@ function playerPlacementRandom(playerIDs, constraints = undefined)
 	let attempts = 0;
 	let resets = 0;
 
-	let mapCenter = g_Map.getCenter();
+	const mapCenter = g_Map.getCenter();
 	let playerMinDistSquared = Math.square(fractionToTiles(0.25));
-	let borderDistance = fractionToTiles(0.08);
+	const borderDistance = fractionToTiles(0.08);
 
-	let area = createArea(new MapBoundsPlacer(), undefined, new AndConstraint(constraints));
+	const area = createArea(new MapBoundsPlacer(), undefined, new AndConstraint(constraints));
 
 	for (let i = 0; i < getNumPlayers(); ++i)
 	{
@@ -747,8 +903,8 @@ function groupPlayersByArea(playerIDs, locations)
 
 		for (let i = 1; i < playerIDs.length; ++i)
 		{
-			let team1 = getPlayerTeam(playerIDs[i - 1]);
-			let team2 = getPlayerTeam(playerIDs[i]);
+			const team1 = getPlayerTeam(playerIDs[i - 1]);
+			const team2 = getPlayerTeam(playerIDs[i]);
 			++teamSize;
 			if (team1 != -1 && team1 == team2)
 				teamDist += permutation[i - 1].distanceTo(permutation[i]);
@@ -770,7 +926,10 @@ function groupPlayersByArea(playerIDs, locations)
 		}
 	});
 
-	return [playerIDs, minLocations];
+	return {
+		"playerIDs": playerIDs,
+		"playerPosition": minLocations
+	};
 }
 
 /**
@@ -778,9 +937,9 @@ function groupPlayersByArea(playerIDs, locations)
  */
 function groupPlayersCycle(startLocations)
 {
-	let startLocationOrder = sortPointsShortestCycle(startLocations);
+	const startLocationOrder = sortPointsShortestCycle(startLocations);
 
-	let newStartLocations = [];
+	const newStartLocations = [];
 	for (let i = 0; i < startLocations.length; ++i)
 		newStartLocations.push(startLocations[startLocationOrder[i]]);
 
@@ -788,11 +947,11 @@ function groupPlayersCycle(startLocations)
 
 	// Sort players by team
 	let playerIDs = [];
-	let teams = [];
+	const teams = [];
 	for (let i = 0; i < g_MapSettings.PlayerData.length - 1; ++i)
 	{
 		playerIDs.push(i+1);
-		let t = g_MapSettings.PlayerData[i + 1].Team;
+		const t = g_MapSettings.PlayerData[i + 1].Team;
 		if (teams.indexOf(t) == -1 && t !== undefined)
 			teams.push(t);
 	}
@@ -810,7 +969,7 @@ function groupPlayersCycle(startLocations)
 		let maxTeamDist = 0;
 		for (let pi = 0; pi < playerIDs.length - 1; ++pi)
 		{
-			let t1 = getPlayerTeam(playerIDs[(pi + s) % playerIDs.length]);
+			const t1 = getPlayerTeam(playerIDs[(pi + s) % playerIDs.length]);
 
 			if (teams.indexOf(t1) === -1)
 				continue;
@@ -839,7 +998,7 @@ function groupPlayersCycle(startLocations)
 
 	if (bestShift)
 	{
-		let newPlayerIDs = [];
+		const newPlayerIDs = [];
 		for (let i = 0; i < playerIDs.length; ++i)
 			newPlayerIDs.push(playerIDs[(i + bestShift) % playerIDs.length]);
 		playerIDs = newPlayerIDs;
