@@ -3,12 +3,14 @@
  *
  * @param {Object} data - Parameters passed from the code that calls this page into existence.
  */
-function init(data = {})
+function init(data)
 {
-	g_Page = new StructreePage(data);
+	const promise = new Promise(closePageCallback => { g_Page = new StructreePage(closePageCallback); });
 
-	if (data.civ)
+	if (data?.civ)
 		g_Page.civSelection.selectCiv(data.civ);
 	else
 		g_Page.civSelection.selectFirstCiv();
+
+	return promise;
 }
