@@ -3,17 +3,17 @@
  */
 function createReplaySelectionData(selectedDirectory)
 {
-	let replaySelection = Engine.GetGUIObjectByName("replaySelection");
-	let dateTimeFilter = Engine.GetGUIObjectByName("dateTimeFilter");
-	let playersFilter = Engine.GetGUIObjectByName("playersFilter");
-	let mapNameFilter = Engine.GetGUIObjectByName("mapNameFilter");
-	let mapSizeFilter = Engine.GetGUIObjectByName("mapSizeFilter");
-	let populationFilter = Engine.GetGUIObjectByName("populationFilter");
-	let durationFilter = Engine.GetGUIObjectByName("durationFilter");
-	let compatibilityFilter = Engine.GetGUIObjectByName("compatibilityFilter");
-	let singleplayerFilter = Engine.GetGUIObjectByName("singleplayerFilter");
-	let victoryConFilter = Engine.GetGUIObjectByName("victoryConditionFilter");
-	let ratedGamesFilter = Engine.GetGUIObjectByName("ratedGamesFilter");
+	const replaySelection = Engine.GetGUIObjectByName("replaySelection");
+	const dateTimeFilter = Engine.GetGUIObjectByName("dateTimeFilter");
+	const playersFilter = Engine.GetGUIObjectByName("playersFilter");
+	const mapNameFilter = Engine.GetGUIObjectByName("mapNameFilter");
+	const mapSizeFilter = Engine.GetGUIObjectByName("mapSizeFilter");
+	const populationFilter = Engine.GetGUIObjectByName("populationFilter");
+	const durationFilter = Engine.GetGUIObjectByName("durationFilter");
+	const compatibilityFilter = Engine.GetGUIObjectByName("compatibilityFilter");
+	const singleplayerFilter = Engine.GetGUIObjectByName("singleplayerFilter");
+	const victoryConFilter = Engine.GetGUIObjectByName("victoryConditionFilter");
+	const ratedGamesFilter = Engine.GetGUIObjectByName("ratedGamesFilter");
 
 	return {
 		"directory": selectedDirectory,
@@ -84,17 +84,18 @@ function reallyStartVisualReplay(replayDirectory)
 function displayReplayCompatibilityError(replay)
 {
 	var errMsg;
-	if (replayHasSameEngineVersion(replay))
+	if (replayHasCompatibleEngineVersion(replay))
 	{
-		let gameMods = replay.attribs.mods || [];
+		const gameMods = replay.attribs.mods || [];
 		errMsg = translate("This replay needs a different sequence of mods:") + "\n" +
 			comparedModsString(gameMods, g_EngineInfo.mods);
 	}
 	else
 	{
 		errMsg = translate("This replay is not compatible with your version of the game!") + "\n";
-		errMsg += sprintf(translate("Your version: %(version)s"), { "version": g_EngineInfo.engine_version }) + "\n";
-		errMsg += sprintf(translate("Required version: %(version)s"), { "version": replay.attribs.engine_version });
+		errMsg += sprintf(translate("Your version: %(version)s, compatible down to %(compatibleVersion)s"), { "version": g_EngineInfo.engine_version, "compatibleVersion": g_EngineInfo.engine_serialization_version }) + "\n";
+		if (replay.attribs.engine_serialization_version)
+			errMsg += sprintf(translate("Replay version: %(version)s"), { "version": replay.attribs.engine_serialization_version });
 	}
 
 	messageBox(500, 200, errMsg, translate("Incompatible replay"));
@@ -105,11 +106,11 @@ function displayReplayCompatibilityError(replay)
  */
 function showReplaySummary()
 {
-	let selected = Engine.GetGUIObjectByName("replaySelection").selected;
+	const selected = Engine.GetGUIObjectByName("replaySelection").selected;
 	if (selected == -1)
 		return;
 
-	let replay = g_ReplaysFiltered[selected];
+	const replay = g_ReplaysFiltered[selected];
 	if (isReplayCompatible(replay))
 		reallyShowReplaySummary(replay.directory);
 	else
@@ -119,7 +120,7 @@ function showReplaySummary()
 function reallyShowReplaySummary(directory)
 {
 	// Load summary screen data from the selected replay directory
-	let simData = Engine.GetReplayMetadata(directory);
+	const simData = Engine.GetReplayMetadata(directory);
 
 	if (!simData)
 	{
@@ -141,62 +142,38 @@ function reallyShowReplaySummary(directory)
 
 function reloadCache()
 {
-	let selected = Engine.GetGUIObjectByName("replaySelection").selected;
+	const selected = Engine.GetGUIObjectByName("replaySelection").selected;
 	loadReplays(selected > -1 ? createReplaySelectionData(g_ReplaysFiltered[selected].directory) : "", true);
 }
 
 /**
  * Callback.
  */
-function deleteReplayButtonPressed()
+async function deleteReplayButtonPressed()
 {
 	if (!Engine.GetGUIObjectByName("deleteReplayButton").enabled)
 		return;
 
-	if (Engine.HotkeyIsPressed("session.savedgames.noconfirmation"))
-		deleteReplayWithoutConfirmation();
-	else
-		deleteReplay();
-}
-/**
- * Shows a confirmation dialog and deletes the selected replay from the disk in case.
- */
-function deleteReplay()
-{
 	// Get selected replay
 	var selected = Engine.GetGUIObjectByName("replaySelection").selected;
 	if (selected == -1)
 		return;
 
-	var replay = g_ReplaysFiltered[selected];
+	const replayDirectory = g_ReplaysFiltered[selected].directory;
 
-	messageBox(
-		500, 200,
-		translate("Are you sure you want to delete this replay permanently?") + "\n" +
-			escapeText(Engine.GetReplayDirectoryName(replay.directory)),
-		translate("Delete replay"),
-		[translate("No"), translate("Yes")],
-		[null, function() { reallyDeleteReplay(replay.directory); }]
-	);
-}
+	if (!Engine.HotkeyIsPressed("session.savedgames.noconfirmation"))
+	{
+		const buttonIndex = await messageBox(
+			500, 200,
+			translate("Are you sure you want to delete this replay permanently?") + "\n" +
+				escapeText(Engine.GetReplayDirectoryName(replayDirectory)),
+			translate("Delete replay"),
+			[translate("No"), translate("Yes")]);
 
-/**
- * Attempts to delete the selected replay from the disk.
- */
-function deleteReplayWithoutConfirmation()
-{
-	var selected = Engine.GetGUIObjectByName("replaySelection").selected;
-	if (selected > -1)
-		reallyDeleteReplay(g_ReplaysFiltered[selected].directory);
-}
+		if (buttonIndex === 0)
+			return;
+	}
 
-/**
- * Attempts to delete the given replay directory from the disk.
- *
- * @param replayDirectory {string}
- */
-function reallyDeleteReplay(replayDirectory)
-{
 	var replaySelection = Engine.GetGUIObjectByName("replaySelection");
 	var selectedIndex = replaySelection.selected;
 
