@@ -51,19 +51,19 @@ var g_UnitActions =
 {
 	"move":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "walk",
 				"entities": selection,
-				"x": target.x,
-				"z": target.z,
+				"x": position.x,
+				"z": position.z,
 				"queued": queued,
 				"pushFront": pushFront,
 				"formation": g_AutoFormation.getDefault()
 			});
 
-			DrawTargetMarker(target);
+			DrawTargetMarker(position);
 
 			Engine.GuiInterfaceCall("PlaySound", {
 				"name": "order_walk",
@@ -85,7 +85,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("move", target, selection);
+			const actionInfo = getActionInfo("move", target, selection);
 			return actionInfo.possible && {
 				"type": "move",
 				"firstAbleEntity": actionInfo.entity
@@ -96,7 +96,7 @@ var g_UnitActions =
 
 	"attack-move":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			let targetClasses;
 			if (Engine.HotkeyIsPressed("session.attackmoveUnit"))
@@ -107,15 +107,15 @@ var g_UnitActions =
 			Engine.PostNetworkCommand({
 				"type": "attack-walk",
 				"entities": selection,
-				"x": target.x,
-				"z": target.z,
+				"x": position.x,
+				"z": position.z,
 				"targetClasses": targetClasses,
 				"queued": queued,
 				"pushFront": pushFront,
 				"formation": g_AutoFormation.getNull()
 			});
 
-			DrawTargetMarker(target);
+			DrawTargetMarker(position);
 
 			Engine.GuiInterfaceCall("PlaySound", {
 				"name": "order_attack_move",
@@ -137,7 +137,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("attack-move", target, selection);
+			const actionInfo = getActionInfo("attack-move", target, selection);
 			return actionInfo.possible && {
 				"type": "attack-move",
 				"cursor": "action-attack-move",
@@ -149,7 +149,7 @@ var g_UnitActions =
 
 	"capture":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "attack",
@@ -181,9 +181,14 @@ var g_UnitActions =
 				})
 			};
 		},
+		"hotkeyActionCheck": function(target, selection)
+		{
+			return Engine.HotkeyIsPressed("session.capture") &&
+				this.actionCheck(target, selection);
+		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("capture", target, selection);
+			const actionInfo = getActionInfo("capture", target, selection);
 			return actionInfo.possible && {
 				"type": "capture",
 				"cursor": "action-capture",
@@ -191,12 +196,12 @@ var g_UnitActions =
 				"firstAbleEntity": actionInfo.entity
 			};
 		},
-		"specificness": 9,
+		"specificness": 10,
 	},
 
 	"attack":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "attack",
@@ -235,7 +240,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("attack", target, selection);
+			const actionInfo = getActionInfo("attack", target, selection);
 			return actionInfo.possible && {
 				"type": "attack",
 				"cursor": "action-attack",
@@ -243,11 +248,11 @@ var g_UnitActions =
 				"firstAbleEntity": actionInfo.entity
 			};
 		},
-		"specificness": 10,
+		"specificness": 9,
 	},
 
 	"call-to-arms": {
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			let targetClasses;
 			if (Engine.HotkeyIsPressed("session.attackmoveUnit"))
@@ -257,11 +262,11 @@ var g_UnitActions =
 			Engine.PostNetworkCommand({
 				"type": "call-to-arms",
 				"entities": selection,
-				"target": target,
+				"position": position,
 				"targetClasses": targetClasses,
 				"queued": queued,
 				"pushFront": pushFront,
-				"allowCapture": true,
+				"allowCapture": Engine.HotkeyIsPressed("session.capture"),
 				"formation": g_AutoFormation.getNull()
 			});
 			return true;
@@ -295,21 +300,21 @@ var g_UnitActions =
 
 	"patrol":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "patrol",
 				"entities": selection,
-				"x": target.x,
-				"z": target.z,
+				"x": position.x,
+				"z": position.z,
 				"target": action.target,
 				"targetClasses": { "attack": g_PatrolTargets },
 				"queued": queued,
-				"allowCapture": false,
+				"allowCapture": Engine.HotkeyIsPressed("session.capture"),
 				"formation": g_AutoFormation.getDefault()
 			});
 
-			DrawTargetMarker(target);
+			DrawTargetMarker(position);
 
 			Engine.GuiInterfaceCall("PlaySound", {
 				"name": "order_patrol",
@@ -336,7 +341,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("patrol", target, selection);
+			const actionInfo = getActionInfo("patrol", target, selection);
 			return actionInfo.possible && {
 				"type": "patrol",
 				"cursor": "action-patrol",
@@ -349,7 +354,7 @@ var g_UnitActions =
 
 	"heal":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "heal",
@@ -375,11 +380,11 @@ var g_UnitActions =
 			    entState.id == targetState.id) // Healers can't heal themselves.
 				return false;
 
-			let unhealableClasses = entState.heal.unhealableClasses;
+			const unhealableClasses = entState.heal.unhealableClasses;
 			if (MatchesClassList(targetState.identity.classes, unhealableClasses))
 				return false;
 
-			let healableClasses = entState.heal.healableClasses;
+			const healableClasses = entState.heal.healableClasses;
 			if (!MatchesClassList(targetState.identity.classes, healableClasses))
 				return false;
 
@@ -387,7 +392,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("heal", target, selection);
+			const actionInfo = getActionInfo("heal", target, selection);
 			return actionInfo.possible && {
 				"type": "heal",
 				"cursor": "action-heal",
@@ -404,7 +409,7 @@ var g_UnitActions =
 	{
 		"preSelectedActionCheck": function(target, selection)
 		{
-			let state = GetEntityState(selection[0]);
+			const state = GetEntityState(selection[0]);
 			if (state && state.builder &&
 			        target && target.constructor && target.constructor.name == "PlacementSupport")
 				return { "type": "construct" };
@@ -415,7 +420,7 @@ var g_UnitActions =
 
 	"repair":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "repair",
@@ -461,7 +466,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("repair", target, selection);
+			const actionInfo = getActionInfo("repair", target, selection);
 			return actionInfo.possible && {
 				"type": "repair",
 				"cursor": "action-repair",
@@ -475,7 +480,7 @@ var g_UnitActions =
 
 	"gather":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "gather",
@@ -514,7 +519,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("gather", target, selection);
+			const actionInfo = getActionInfo("gather", target, selection);
 			return actionInfo.possible && {
 				"type": "gather",
 				"cursor": actionInfo.cursor,
@@ -527,7 +532,7 @@ var g_UnitActions =
 
 	"returnresource":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "returnresource",
@@ -550,7 +555,7 @@ var g_UnitActions =
 			if (!targetState || !targetState.resourceDropsite)
 				return false;
 
-			let playerState = GetSimState().players[entState.player];
+			const playerState = GetSimState().players[entState.player];
 			if (playerState.hasSharedDropsites && targetState.resourceDropsite.shared)
 			{
 				if (!playerCheck(entState, targetState, ["Player", "MutualAlly"]))
@@ -562,7 +567,7 @@ var g_UnitActions =
 			if (!entState.resourceCarrying || !entState.resourceCarrying.length)
 				return false;
 
-			let carriedType = entState.resourceCarrying[0].type;
+			const carriedType = entState.resourceCarrying[0].type;
 			if (targetState.resourceDropsite.types.indexOf(carriedType) == -1)
 				return false;
 
@@ -573,7 +578,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("returnresource", target, selection);
+			const actionInfo = getActionInfo("returnresource", target, selection);
 			return actionInfo.possible && {
 				"type": "returnresource",
 				"cursor": actionInfo.cursor,
@@ -586,7 +591,7 @@ var g_UnitActions =
 
 	"cancel-setup-trade-route":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "cancel-setup-trade-route",
@@ -605,7 +610,7 @@ var g_UnitActions =
 			      targetState.market.naval && hasClass(entState, "Ship")))
 				return false;
 
-			let tradingDetails = Engine.GuiInterfaceCall("GetTradingDetails", {
+			const tradingDetails = Engine.GuiInterfaceCall("GetTradingDetails", {
 				"trader": entState.id,
 				"target": targetState.id
 			});
@@ -622,7 +627,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("cancel-setup-trade-route", target, selection);
+			const actionInfo = getActionInfo("cancel-setup-trade-route", target, selection);
 			return actionInfo.possible && {
 				"type": "cancel-setup-trade-route",
 				"cursor": "action-cancel-setup-trade-route",
@@ -636,7 +641,7 @@ var g_UnitActions =
 
 	"setup-trade-route":
 	{
-		"execute": function(target, action, selection, queued)
+		"execute": function(position, action, selection, queued)
 		{
 			Engine.PostNetworkCommand({
 				"type": "setup-trade-route",
@@ -663,7 +668,7 @@ var g_UnitActions =
 			      targetState.market.naval && hasClass(entState, "Ship")))
 				return false;
 
-			let tradingDetails = Engine.GuiInterfaceCall("GetTradingDetails", {
+			const tradingDetails = Engine.GuiInterfaceCall("GetTradingDetails", {
 				"trader": entState.id,
 				"target": targetState.id
 			});
@@ -708,6 +713,8 @@ var g_UnitActions =
 						"gain": getTradingTooltip(tradingDetails.gain)
 					});
 				break;
+			default:
+				error("Unknown type for tradingDetails: " + tradingDetails.type);
 			}
 
 			return {
@@ -717,7 +724,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("setup-trade-route", target, selection);
+			const actionInfo = getActionInfo("setup-trade-route", target, selection);
 			if (actionInfo.disabled)
 				return {
 					"type": "none",
@@ -739,7 +746,7 @@ var g_UnitActions =
 
 	"occupy-turret":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "occupy-turret",
@@ -767,7 +774,7 @@ var g_UnitActions =
 				!point.allowedClasses || MatchesClassList(entState.identity.classes, point.allowedClasses)))
 				return false;
 
-			let occupiedTurrets = targetState.turretHolder.turretPoints.filter(point => point.entity != null);
+			const occupiedTurrets = targetState.turretHolder.turretPoints.filter(point => point.entity != null);
 			let tooltip = sprintf(translate("Current turrets: %(occupied)s/%(capacity)s"), {
 				"occupied": occupiedTurrets.length,
 				"capacity": targetState.turretHolder.turretPoints.length
@@ -796,7 +803,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("occupy-turret", target, selection);
+			const actionInfo = getActionInfo("occupy-turret", target, selection);
 			return actionInfo.possible && {
 				"type": "occupy-turret",
 				"cursor": "action-occupy-turret",
@@ -810,7 +817,7 @@ var g_UnitActions =
 
 	"garrison":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "garrison",
@@ -870,7 +877,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("garrison", target, selection);
+			const actionInfo = getActionInfo("garrison", target, selection);
 			return actionInfo.possible && {
 				"type": "garrison",
 				"cursor": "action-garrison",
@@ -884,7 +891,7 @@ var g_UnitActions =
 
 	"guard":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "guard",
@@ -926,7 +933,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("guard", target, selection);
+			const actionInfo = getActionInfo("guard", target, selection);
 			return actionInfo.possible && {
 				"type": "guard",
 				"cursor": "action-guard",
@@ -939,7 +946,7 @@ var g_UnitActions =
 
 	"collect-treasure":
 	{
-		"execute": function(target, action, selection, queued)
+		"execute": function(position, action, selection, queued)
 		{
 			Engine.PostNetworkCommand({
 				"type": "collect-treasure",
@@ -969,7 +976,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("collect-treasure", target, selection);
+			const actionInfo = getActionInfo("collect-treasure", target, selection);
 			return actionInfo.possible && {
 				"type": "collect-treasure",
 				"cursor": actionInfo.cursor,
@@ -982,7 +989,7 @@ var g_UnitActions =
 
 	"remove-guard":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "remove-guard",
@@ -1012,7 +1019,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("remove-guard", target, selection);
+			const actionInfo = getActionInfo("remove-guard", target, selection);
 			return actionInfo.possible && {
 				"type": "remove-guard",
 				"cursor": "action-remove-guard",
@@ -1022,20 +1029,99 @@ var g_UnitActions =
 		"specificness": 41,
 	},
 
+	"focus-fire":
+	{
+		"execute": function(position, action, selection, queued, pushFront)
+		{
+			Engine.PostNetworkCommand({
+				"type": "focus-fire",
+				"entities": selection,
+				"x": position.x,
+				"z": position.z,
+				"target": action.target,
+				"data": action.data,
+				"queued": queued,
+				"pushFront": pushFront
+			});
+
+			if (action.data.sound)
+				Engine.GuiInterfaceCall("PlaySound", {
+					"name": "focus_fire",
+					"entity": action.firstAbleEntity
+				});
+
+			return true;
+		},
+		"getActionInfo": function(entState, targetState)
+		{
+			if (!entState.rallyPoint)
+				return undefined;
+
+			let tooltip;
+			const data = { "command": "walk" };
+			data.sound = false;
+
+			if (entState.attack && Engine.HotkeyIsPressed("session.focusfire"))
+			{
+				data.command = "attack-only";
+				if (targetState && playerCheck(entState, targetState, ["Enemy"]) && !targetState.resourceSupply)
+				{
+					data.target = targetState.id;
+					data.sound = true;
+				}
+				return {
+					"possible": true,
+					"data": data,
+					"position": targetState && targetState.position,
+					"cursor": "action-target",
+					"tooltip": tooltip
+				};
+			}
+			return undefined;
+		},
+		"hotkeyActionCheck": function(target, selection)
+		{
+			// Hotkeys are checked in the actionInfo.
+			return this.actionCheck(target, selection);
+		},
+		"actionCheck": function(target, selection)
+		{
+			// We want commands to units take precedence.
+			if (selection.some(ent => {
+				const entState = GetEntityState(ent);
+				return entState && !!entState.unitAI;
+			}))
+				return false;
+
+			const actionInfo = getActionInfo("focus-fire", target, selection);
+
+			return actionInfo.possible && {
+				"type": "focus-fire",
+				"cursor": actionInfo.cursor,
+				"data": actionInfo.data,
+				"target": target,
+				"tooltip": actionInfo.tooltip,
+				"position": actionInfo.position,
+				"firstAbleEntity": actionInfo.entity
+			};
+		},
+		"specificness": 6,
+	},
+
 	"set-rallypoint":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			// if there is a position set in the action then use this so that when setting a
 			// rally point on an entity it is centered on that entity
 			if (action.position)
-				target = action.position;
+				position = action.position;
 
 			Engine.PostNetworkCommand({
 				"type": "set-rallypoint",
 				"entities": selection,
-				"x": target.x,
-				"z": target.z,
+				"x": position.x,
+				"z": position.z,
 				"data": action.data,
 				"queued": queued
 			});
@@ -1043,8 +1129,8 @@ var g_UnitActions =
 			// Display rally point at the new coordinates, to avoid display lag
 			Engine.GuiInterfaceCall("DisplayRallyPoint", {
 				"entities": selection,
-				"x": target.x,
-				"z": target.z,
+				"x": position.x,
+				"z": position.z,
 				"queued": queued
 			});
 
@@ -1067,7 +1153,7 @@ var g_UnitActions =
 			let tooltip;
 			let disabled = false;
 			// default to walking there (or attack-walking if hotkey pressed)
-			let data = { "command": "walk" };
+			const data = { "command": "walk" };
 			let cursor = "";
 
 			if (isAttackMovePressed())
@@ -1114,7 +1200,7 @@ var g_UnitActions =
 				data.target = targetState.id;
 				cursor = "action-garrison";
 
-				let occupiedTurrets = targetState.turretHolder.turretPoints.filter(point => point.entity != null);
+				const occupiedTurrets = targetState.turretHolder.turretPoints.filter(point => point.entity != null);
 				tooltip = sprintf(translate("Current turrets: %(occupied)s/%(capacity)s"), {
 					"occupied": occupiedTurrets.length,
 					"capacity": targetState.turretHolder.turretPoints.length
@@ -1125,7 +1211,7 @@ var g_UnitActions =
 			}
 			else if (targetState && targetState.resourceSupply)
 			{
-				let resourceType = targetState.resourceSupply.type;
+				const resourceType = targetState.resourceSupply.type;
 				cursor = "action-gather-" + resourceType.specific;
 
 				data.command = "gather-near-position";
@@ -1159,13 +1245,13 @@ var g_UnitActions =
 						if ((trader = GetTemplateData(entState.trainer.entities[i]).trader))
 							break;
 
-				let traderData = {
+				const traderData = {
 					"firstMarket": entState.id,
 					"secondMarket": targetState.id,
 					"template": trader
 				};
 
-				let gain = Engine.GuiInterfaceCall("GetTradingRouteGain", traderData);
+				const gain = Engine.GuiInterfaceCall("GetTradingRouteGain", traderData);
 				if (gain)
 				{
 					data.command = "trade";
@@ -1198,7 +1284,15 @@ var g_UnitActions =
 			{
 				data.target = targetState.id;
 				data.command = "attack";
-				cursor = "action-attack";
+				if (targetState.hitpoints)
+					cursor = "action-attack";
+				else if (targetState.capturePoints)
+				{
+					cursor = "action-capture";
+					data.allowCapture = true;
+				}
+				else
+					return false;
 			}
 
 			return {
@@ -1220,12 +1314,12 @@ var g_UnitActions =
 		{
 			// We want commands to units take precedence.
 			if (selection.some(ent => {
-				let entState = GetEntityState(ent);
+				const entState = GetEntityState(ent);
 				return entState && !!entState.unitAI;
 			}))
 				return false;
 
-			let actionInfo = getActionInfo("set-rallypoint", target, selection);
+			const actionInfo = getActionInfo("set-rallypoint", target, selection);
 			if (actionInfo.disabled)
 				return {
 					"type": "none",
@@ -1248,7 +1342,7 @@ var g_UnitActions =
 
 	"unset-rallypoint":
 	{
-		"execute": function(target, action, selection, queued, pushFront)
+		"execute": function(position, action, selection, queued, pushFront)
 		{
 			Engine.PostNetworkCommand({
 				"type": "unset-rallypoint",
@@ -1273,7 +1367,7 @@ var g_UnitActions =
 		},
 		"actionCheck": function(target, selection)
 		{
-			let actionInfo = getActionInfo("unset-rallypoint", target, selection);
+			const actionInfo = getActionInfo("unset-rallypoint", target, selection);
 			return actionInfo.possible && {
 				"type": "unset-rallypoint",
 				"cursor": "action-unset-rally",
@@ -1287,16 +1381,16 @@ var g_UnitActions =
 	// when only uncontrollable entities are selected.
 	"uncontrollable":
 	{
-		"execute": function(target, action, selection, queued)
+		"execute": function(position, action, selection, queued)
 		{
 			return true;
 		},
 		"actionCheck": function(target, selection)
 		{
 			// Only show this action if all entities are marked uncontrollable.
-			let playerState = g_SimState.players[g_ViewedPlayer];
+			const playerState = g_SimState.players[g_ViewedPlayer];
 			if (playerState && playerState.controlsAll || selection.some(ent => {
-				let entState = GetEntityState(ent);
+				const entState = GetEntityState(ent);
 				return entState && entState.identity && entState.identity.controllable;
 			}))
 				return false;
@@ -1312,7 +1406,7 @@ var g_UnitActions =
 
 	"none":
 	{
-		"execute": function(target, action, selection, queued)
+		"execute": function(position, action, selection, queued)
 		{
 			return true;
 		},
@@ -1332,7 +1426,7 @@ var g_EntityCommands =
 		"getInfo": function(entStates)
 		{
 			let count = 0;
-			for (let entState of entStates)
+			for (const entState of entStates)
 			{
 				if (!entState.garrisonHolder)
 					continue;
@@ -1340,7 +1434,7 @@ var g_EntityCommands =
 				if (allowedPlayersCheck([entState], ["Player"]))
 					count += entState.garrisonHolder.entities.length;
 				else
-					for (let entity of entState.garrisonHolder.entities)
+					for (const entity of entState.garrisonHolder.entities)
 						if (allowedPlayersCheck([GetEntityState(entity)], ["Player"]))
 							++count;
 			}
@@ -1350,7 +1444,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.unload") +
-				           translate("Unload All."),
+					translate("Unload All") + "\n" +
+					bodyFont(translate("Order all units to leave the selected entities.")),
 				"icon": "garrison-out.png",
 				"count": count,
 				"enabled": true
@@ -1367,7 +1462,7 @@ var g_EntityCommands =
 		"getInfo": function(entStates)
 		{
 			let count = 0;
-			for (let entState of entStates)
+			for (const entState of entStates)
 			{
 				if (!entState.turretHolder)
 					continue;
@@ -1375,7 +1470,7 @@ var g_EntityCommands =
 				if (allowedPlayersCheck([entState], ["Player"]))
 					count += entState.turretHolder.turretPoints.filter(turretPoint => turretPoint.entity && turretPoint.ejectable).length;
 				else
-					for (let turretPoint of entState.turretHolder.turretPoints)
+					for (const turretPoint of entState.turretHolder.turretPoints)
 						if (turretPoint.entity && allowedPlayersCheck([GetEntityState(turretPoint.entity)], ["Player"]))
 							++count;
 			}
@@ -1385,7 +1480,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.unloadturrets") +
-				           translate("Unload Turrets."),
+					translate("Unload Turrets") + "\n" +
+					bodyFont(translate("Order all units to leave the selected turret points.")),
 				"icon": "garrison-out.png",
 				"count": count,
 				"enabled": true
@@ -1405,10 +1501,12 @@ var g_EntityCommands =
 				{
 					"tooltip":
 						colorizeHotkey("%(hotkey)s" + " ", "session.kill") +
-						translate("Destroy the selected units or structures.") + "\n" +
-						colorizeHotkey(
-							translate("Use %(hotkey)s to avoid the confirmation dialog."),
-							"session.noconfirmation"
+						translate("Self-Destruct") + "\n" +
+						bodyFont(translate("Destroy the selected entities.") + "\n" +
+							colorizeHotkey(
+								translate("Use %(hotkey)s to avoid the confirmation dialog."),
+								"session.noconfirmation"
+							)
 						),
 					"icon": "kill_small.png",
 					"enabled": true
@@ -1425,7 +1523,7 @@ var g_EntityCommands =
 		},
 		"execute": function(entStates)
 		{
-			let entityIDs = entStates.reduce(
+			const entityIDs = entStates.reduce(
 				(ids, entState) => {
 					if (!isUndeletable(entState))
 						ids.push(entState.id);
@@ -1436,7 +1534,7 @@ var g_EntityCommands =
 			if (!entityIDs.length)
 				return;
 
-			let deleteSelection = () => Engine.PostNetworkCommand({
+			const deleteSelection = () => Engine.PostNetworkCommand({
 				"type": "delete-entities",
 				"entities": entityIDs
 			});
@@ -1452,12 +1550,14 @@ var g_EntityCommands =
 	"stop": {
 		"getInfo": function(entStates)
 		{
-			if (entStates.every(entState => !entState.unitAI))
+			// Don't show generic option to abort if not applicable or in case of guard, which has its own abort action
+			if (entStates.every(entState => !entState.unitAI || entState.unitAI.isIdle || entState.unitAI.isGuarding))
 				return false;
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.stop") +
-				           translate("Abort the current order."),
+					translate("Abort") + "\n" +
+					bodyFont(translate("Cancel the current orders for the selected units.")),
 				"icon": "stop.png",
 				"enabled": true
 			};
@@ -1478,7 +1578,8 @@ var g_EntityCommands =
 				return false;
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.calltoarms") +
-						translate("Send the selected units on attack move to the specified location after dropping resources."),
+						translate("Attack") + "\n" +
+						bodyFont(translate("Send the selected units on attack move to the specified location after dropping resources.")),
 				"icon": "call-to-arms.png",
 				"enabled": true
 			};
@@ -1500,7 +1601,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.garrison") +
-				           translate("Order the selected units to garrison in a structure or unit."),
+					translate("Garrison") + "\n" +
+					bodyFont(translate("Order the selected units to garrison in a structure or another unit.")),
 				"icon": "garrison.png",
 				"enabled": true
 			};
@@ -1522,7 +1624,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.occupyturret") +
-				           translate("Order the selected units to occupy a turret point."),
+					translate("Occupy Turret") + "\n" +
+					bodyFont(translate("Order the selected units to occupy a turret point.")),
 				"icon": "occupy-turret.png",
 				"enabled": true
 			};
@@ -1544,7 +1647,8 @@ var g_EntityCommands =
 				return false;
 
 			return {
-				"tooltip": translate("Unload"),
+				"tooltip": translate("Unload") + "\n" +
+					bodyFont(translate("Order the selected units to leave their turret points.")),
 				"icon": "leave-turret.png",
 				"enabled": true
 			};
@@ -1564,7 +1668,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.repair") +
-				           translate("Order the selected units to repair a structure, ship, or siege engine."),
+					translate("Repair") + "\n" +
+					bodyFont(translate("Order the selected units to repair a structure, ship, or siege engine.")),
 				"icon": "repair.png",
 				"enabled": true
 			};
@@ -1585,7 +1690,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "camera.rallypointfocus") +
-				           translate("Focus on Rally Point."),
+					translate("Focus on Rally Point") + "\n" +
+					bodyFont(translate("Center the view on the selected rally point.")),
 				"icon": "focus-rally.png",
 				"enabled": true
 			};
@@ -1594,14 +1700,14 @@ var g_EntityCommands =
 		{
 			// TODO: Would be nicer to cycle between the rallypoints of multiple entities instead of just using the first
 			let focusTarget;
-			for (let entState of entStates)
+			for (const entState of entStates)
 				if (entState.rallyPoint && entState.rallyPoint.position)
 				{
 					focusTarget = entState.rallyPoint.position;
 					break;
 				}
 			if (!focusTarget)
-				for (let entState of entStates)
+				for (const entState of entStates)
 					if (entState.position)
 					{
 						focusTarget = entState.position;
@@ -1622,7 +1728,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.backtowork") +
-				           translate("Back to Work"),
+					translate("Back to Work") + "\n" +
+					bodyFont(translate("Order the selected units to resume their work.")),
 				"icon": "back-to-work.png",
 				"enabled": true
 			};
@@ -1643,7 +1750,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.guard") +
-				           translate("Order the selected units to guard a structure or unit."),
+					translate("Guard") + "\n" +
+					bodyFont(translate("Order the selected units to guard a structure or unit.")),
 				"icon": "add-guard.png",
 				"enabled": true
 			};
@@ -1663,7 +1771,8 @@ var g_EntityCommands =
 				return false;
 
 			return {
-				"tooltip": translate("Remove guard"),
+				"tooltip": translate("Abort Guard") + "\n" +
+					bodyFont(translate("Order the selected units to stop guarding.")),
 				"icon": "remove-guard.png",
 				"enabled": true
 			};
@@ -1682,7 +1791,9 @@ var g_EntityCommands =
 				return false;
 
 			return {
-				"tooltip": translate("Barter & Trade"),
+				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.gui.barter.toggle") +
+					translate("Barter & Trade") + "\n" +
+					bodyFont(translate("Open the dialog for managing resource trading and bartering.")),
 				"icon": "economics.png",
 				"enabled": true
 			};
@@ -1702,8 +1813,8 @@ var g_EntityCommands =
 
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.patrol") +
-				           translate("Patrol") + "\n" +
-				           translate("Attack all encountered enemy units while avoiding structures."),
+					translate("Patrol") + "\n" +
+					bodyFont(translate("Order to repeatedly go to a point and come back, attacking all enemies along the way.")),
 				"icon": "patrol.png",
 				"enabled": true
 			};
@@ -1719,7 +1830,7 @@ var g_EntityCommands =
 	"share-dropsite": {
 		"getInfo": function(entStates)
 		{
-			let sharableEntities = entStates.filter(
+			const sharableEntities = entStates.filter(
 				entState => entState.resourceDropsite && entState.resourceDropsite.sharable);
 			if (!sharableEntities.length)
 				return false;
@@ -1731,19 +1842,21 @@ var g_EntityCommands =
 
 			return sharableEntities.some(entState => !entState.resourceDropsite.shared) ?
 				{
-					"tooltip": translate("Press to allow allies to use this dropsite"),
+					"tooltip": translate("Share Dropsite") + "\n" +
+						bodyFont(translate("Allow allies to use this dropsite, now locked.")),
 					"icon": "locked_small.png",
 					"enabled": true
 				} :
 				{
-					"tooltip": translate("Press to prevent allies from using this dropsite"),
+					"tooltip": translate("Lock Dropsite") + "\n" +
+						bodyFont(translate("Prevent allies from using this dropsite, now shared.")),
 					"icon": "unlocked_small.png",
 					"enabled": true
 				};
 		},
 		"execute": function(entStates)
 		{
-			let sharableEntities = entStates.filter(
+			const sharableEntities = entStates.filter(
 				entState => entState.resourceDropsite && entState.resourceDropsite.sharable);
 			if (sharableEntities)
 				Engine.PostNetworkCommand({
@@ -1758,27 +1871,29 @@ var g_EntityCommands =
 	"is-dropsite-shared": {
 		"getInfo": function(entStates)
 		{
-			let shareableEntities = entStates.filter(
+			const shareableEntities = entStates.filter(
 				entState => entState.resourceDropsite && entState.resourceDropsite.sharable);
 			if (!shareableEntities.length)
 				return false;
 
-			let player = Engine.GetPlayerID();
-			let simState = GetSimState();
+			const player = Engine.GetPlayerID();
+			const simState = GetSimState();
 			if (!g_IsObserver && !simState.players[player].hasSharedDropsites ||
 				shareableEntities.every(entState => controlsPlayer(entState.player)))
 				return false;
 
 			if (!shareableEntities.every(entState => entState.resourceDropsite.shared))
 				return {
-					"tooltip": translate("The use of this dropsite is prohibited"),
+					"tooltip": translate("Locked Dropsite") + "\n" +
+						bodyFont(translate("The use of this dropsite is prohibited.")),
 					"icon": "locked_small.png",
 					"enabled": false
 				};
 
 			return {
-				"tooltip": g_IsObserver ? translate("Allies are allowed to use this dropsite.") :
-					translate("You are allowed to use this dropsite"),
+				"tooltip": translate("Shared Dropsite") + "\n" +
+					bodyFont(g_IsObserver ? translate("Allies are allowed to use this dropsite.") :
+						translate("You are allowed to use this dropsite.")),
 				"icon": "unlocked_small.png",
 				"enabled": false
 			};
@@ -1797,7 +1912,8 @@ var g_EntityCommands =
 				return false;
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.queueunit.autoqueueon") +
-						   translate("Activate auto-queue for selected structures."),
+					translate("Activate Auto-Queue") + "\n" +
+					bodyFont(translate("Activate the production auto-queue for the selected structures.")),
 				"icon": "autoqueue-on.png",
 				"enabled": true
 			};
@@ -1817,7 +1933,8 @@ var g_EntityCommands =
 				return false;
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.queueunit.autoqueueoff") +
-						   translate("Deactivate auto-queue for selected structures."),
+					translate("Deactivate Auto-Queue") + "\n" +
+					bodyFont(translate("Deactivate the production auto-queue for the selected structures.")),
 				"icon": "autoqueue-off.png",
 				"enabled": true
 			};
@@ -1833,8 +1950,8 @@ var g_EntityCommands =
 
 function playerCheck(entState, targetState, validPlayers)
 {
-	let playerState = GetSimState().players[entState.player];
-	for (let player of validPlayers)
+	const playerState = GetSimState().players[entState.player];
+	for (const player of validPlayers)
 		if (player == "Gaia" && targetState.player == 0 ||
 		    player == "Player" && targetState.player == entState.player ||
 		    playerState["is" + player] && playerState["is" + player][targetState.player])
@@ -1857,8 +1974,8 @@ function allowedPlayersCheck(entStates, validPlayers)
 {
 	// Assume we can only select entities from one player,
 	// or it does not matter (e.g. observer).
-	let targetState = entStates[0];
-	let playerState = GetSimState().players[Engine.GetPlayerID()];
+	const targetState = entStates[0];
+	const playerState = GetSimState().players[Engine.GetPlayerID()];
 
 	return validPlayers.some(player =>
 		player == "Observer" && g_IsObserver ||
@@ -1877,7 +1994,7 @@ function hasClass(entState, className)
  */
 function isUndeletable(entState)
 {
-	let playerState = g_SimState.players[entState.player];
+	const playerState = g_SimState.players[entState.player];
 	if (playerState && playerState.controlsAll)
 		return false;
 
@@ -1893,24 +2010,32 @@ function isUndeletable(entState)
 	return false;
 }
 
-function DrawTargetMarker(target)
+function DrawTargetMarker(position)
 {
 	Engine.GuiInterfaceCall("AddTargetMarker", {
 		"template": g_TargetMarker.move,
-		"x": target.x,
-		"z": target.z
+		"x": position.x,
+		"z": position.z
 	});
 }
 
-function displayFlare(target, playerID)
+function renderAndPlayFlare(position, playerGUID)
 {
+	const playerID = g_PlayerAssignments[playerGUID].player;
 	Engine.GuiInterfaceCall("AddTargetMarker", {
 		"template": g_TargetMarker.map_flare,
-		"x": target.x,
-		"z": target.z,
-		"owner": playerID
+		"x": position.x,
+		"z": position.z,
+		// Set the owner to gaia if the flare was sent by an observer (to make the target marker white).
+		"owner": playerID != -1 ? playerID : 0
+	});
+	g_MiniMapPanel.flare(position, playerID);
+	Engine.PlayUISound(g_FlareSound, false);
+	addChatMessage({
+		"type": "flare",
+		"guid": playerGUID,
+		"position": position
 	});
-	g_MiniMapPanel.flare(target, playerID);
 }
 
 function getCommandInfo(command, entStates)
@@ -1928,15 +2053,15 @@ function getActionInfo(action, target, selection)
 	// Look at the first targeted entity
 	// (TODO: maybe we eventually want to look at more, and be more context-sensitive?
 	// e.g. prefer to attack an enemy unit, even if some friendly units are closer to the mouse)
-	let targetState = GetEntityState(target);
+	const targetState = GetEntityState(target);
 
-	let simState = GetSimState();
-	let playerState = g_SimState.players[g_ViewedPlayer];
+	const simState = GetSimState();
+	const playerState = g_SimState.players[g_ViewedPlayer];
 
 	// Check if any entities in the selection can do some of the available actions.
-	for (let entityID of selection)
+	for (const entityID of selection)
 	{
-		let entState = GetEntityState(entityID);
+		const entState = GetEntityState(entityID);
 		if (!entState)
 			continue;
 
@@ -1945,7 +2070,7 @@ function getActionInfo(action, target, selection)
 
 		if (g_UnitActions[action] && g_UnitActions[action].getActionInfo)
 		{
-			let r = g_UnitActions[action].getActionInfo(entState, targetState, simState);
+			const r = g_UnitActions[action].getActionInfo(entState, targetState, simState);
 			if (r && r.possible)
 			{
 				r.entity = entityID;
